==> haskell-xml-1.3.14-11-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-xml.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xml
version: 1.3.14
id: xml-1.3.14-gmCpsUXEJ0Cd36ZPTskAU
key: xml-1.3.14-gmCpsUXEJ0Cd36ZPTskAU
license: BSD3
copyright: (c) 2007-2008 Galois Inc.
maintainer: diatchki@galois.com
homepage: http://code.galois.com
synopsis: A simple XML library.
description:
    A simple XML library.
category: Text, XML
author: Galois Inc.
exposed: True
indefinite: False
exposed-modules:
    Text.XML.Light Text.XML.Light.Cursor Text.XML.Light.Input
    Text.XML.Light.Lexer Text.XML.Light.Output Text.XML.Light.Proc
    Text.XML.Light.Types
abi: d10a974e22e128d84bfcf55c875efa2c
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/xml-1.3.14
library-dirs: /usr/lib/ghc-8.2.2/site-local/xml-1.3.14
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/xml-1.3.14
hs-libraries: HSxml-1.3.14-gmCpsUXEJ0Cd36ZPTskAU
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
haddock-interfaces: /usr/share/doc/haskell-xml/html/xml.haddock
haddock-html: /usr/share/doc/haskell-xml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xml-1.3.14-12-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-xml.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xml
version: 1.3.14
id: xml-1.3.14-1QOvnW05iRMh383OQN419
key: xml-1.3.14-1QOvnW05iRMh383OQN419
license: BSD3
copyright: (c) 2007-2008 Galois Inc.
maintainer: diatchki@galois.com
homepage: http://code.galois.com
synopsis: A simple XML library.
description:
    A simple XML library.
category: Text, XML
author: Galois Inc.
exposed: True
indefinite: False
exposed-modules:
    Text.XML.Light Text.XML.Light.Cursor Text.XML.Light.Input
    Text.XML.Light.Lexer Text.XML.Light.Output Text.XML.Light.Proc
    Text.XML.Light.Types
abi: a7056b3de174482244e4897529e3aaf7
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/xml-1.3.14
library-dirs: /usr/lib/ghc-8.2.2/site-local/xml-1.3.14
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/xml-1.3.14
hs-libraries: HSxml-1.3.14-1QOvnW05iRMh383OQN419
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
haddock-interfaces: /usr/share/doc/haskell-xml/html/xml.haddock
haddock-html: /usr/share/doc/haskell-xml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
